package com.goldenwater.slgc.service;

import java.util.List;
import com.goldenwater.slgc.domain.CmsArticleFile;

/** 内容文件 Service */
public interface CmsArticleFileService {
    /**
     * 查询内容文件列表
     *
     * @param cmsArticleFile 查询条件
     * @return 内容文件列表
     */
    public List<CmsArticleFile> selectCmsArticleFileList(CmsArticleFile cmsArticleFile);

    /**
     * 通过文件ID查询内容文件
     *
     * @param fileId 文件ID
     * @return 内容文件
     */
    public CmsArticleFile selectCmsArticleFileById(String fileId);

    /**
     * 删除内容文件
     *
     * @param fileIds 文件ID数组
     * @return 删除行数
     */
    public int deleteCmsArticleFileByIds(String[] fileIds);

    /**
     * 新增内容文件
     *
     * @param cmsArticleFile 内容文件
     * @return 插入行数
     */
    public int insertCmsArticleFile(CmsArticleFile cmsArticleFile);

    /**
     * 修改内容文件
     *
     * @param cmsArticleFile 内容文件
     * @return 更新行数
     */
    public int updateCmsArticleFile(CmsArticleFile cmsArticleFile);

    /**
     * 根据文章ID删除文件
     *
     * @param aid 文章ID
     * @return 删除行数
     */
    public int deleteByAid(String aid);
}
